package com.ruoyi.system.service.columns.impl;

import java.util.List;

import com.ruoyi.system.domain.columns.YjHealthy;
import com.ruoyi.system.mapper.colums.YjHealthyMapper;
import com.ruoyi.system.service.columns.IYjHealthyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 健康饮食Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-10-29
 */
@Service
public class YjHealthyServiceImpl implements IYjHealthyService
{
    @Autowired
    private YjHealthyMapper yjHealthyMapper;

    /**
     * 查询健康饮食
     * 
     * @param id 健康饮食主键
     * @return 健康饮食
     */
    @Override
    public YjHealthy selectYjHealthyById(String id)
    {
        return yjHealthyMapper.selectYjHealthyById(id);
    }

    /**
     * 查询健康饮食列表
     * 
     * @param yjHealthy 健康饮食
     * @return 健康饮食
     */
    @Override
    public List<YjHealthy> selectYjHealthyList(YjHealthy yjHealthy)
    {
        return yjHealthyMapper.selectYjHealthyList(yjHealthy);
    }

    /**
     * 新增健康饮食
     * 
     * @param yjHealthy 健康饮食
     * @return 结果
     */
    @Override
    public int insertYjHealthy(YjHealthy yjHealthy)
    {
        return yjHealthyMapper.insertYjHealthy(yjHealthy);
    }

    /**
     * 修改健康饮食
     * 
     * @param yjHealthy 健康饮食
     * @return 结果
     */
    @Override
    public int updateYjHealthy(YjHealthy yjHealthy)
    {
        return yjHealthyMapper.updateYjHealthy(yjHealthy);
    }

    /**
     * 批量删除健康饮食
     * 
     * @param ids 需要删除的健康饮食主键
     * @return 结果
     */
    @Override
    public int deleteYjHealthyByIds(String[] ids)
    {
        return yjHealthyMapper.deleteYjHealthyByIds(ids);
    }

    /**
     * 删除健康饮食信息
     * 
     * @param id 健康饮食主键
     * @return 结果
     */
    @Override
    public int deleteYjHealthyById(String id)
    {
        return yjHealthyMapper.deleteYjHealthyById(id);
    }
}
